@@ -143,7 +143,7 @@ class RabbitMQueue(Queue):
         super().__init__(name)
         credentials = None
         if username is not None and password is not None:
-            credentials = pika.PlainCredentials("username", "password")
+            credentials = pika.PlainCredentials(username, password)
             self.__parameters = pika.ConnectionParameters(
                 host=address, credentials=credentials
             )
@@ -178,9 +178,31 @@ class RabbitMQueue(Queue):
     ) -> Any:  # noqa: D102
         raise NotImplementedError(
             "Get methode is not implemented forRabbitMQueue. "
-            "Use consumer method instead"
+            "Use consumer or start_consuming method instead"
         )
 
+    def start_consuming(
+        self, callback: callable, deserializer: callable = None
+    ):
+        assert callable(callback)
+
+        def _callback(channel, method, properties, body):
+            try:
+                message = deserializer(body.decode("utf-8"))
+                callback(message)
+            except Exception as e:
+                raise e
+            finally:
+                channel.basic_ack(delivery_tag=method.delivery_tag)
+
+        connection = pika.BlockingConnection(self.__parameters)
+        channel = connection.channel()
+        channel.queue_declare(queue=self.name, durable=True)
+
+        channel.basic_qos(prefetch_count=1)
+        channel.basic_consume(queue=self.name, on_message_callback=_callback)
+        channel.start_consuming()
+
     def consumer(self, callback: callable, deserializer: callable = None):
         assert callable(callback)
 
